powered by
List of Brazilian fertilizer consumption series for N, P2O5, K2O. All series are numeric and ordered by time.
brazil_n: nitrogen consumption from 1961 to 2020.
brazil_p2o5: phosphate consumption from 1961 to 2020.
brazil_k2o: potash consumption from 1961 to 2020.
data(fertilizers)
list of fertilizers' time series.
International Fertilizer Association (IFA): https://www.fertilizer.org
# Load dataset and preview one of the series (nitrogen) data(fertilizers) head(fertilizers$brazil_n)
Run the code above in your browser using DataLab