Learn R Programming

tspredit (version 1.2.747)

ts_reg: TSReg

Description

Base class for time series regression models that operate directly on time series (non-sliding-window specialization).

Usage

ts_reg()

Arguments

Value

A ts_reg object (S3) to be extended by concrete models.

Details

This class is intended to be subclassed by modeling backends that do not require the sliding-window interface. Methods such as fit(), predict(), and evaluate() dispatch on this class.

Examples

Run this code
# Abstract base class — instantiate concrete subclasses instead
# Examples: ts_mlp(), ts_rf(), ts_svm(), ts_arima()

Run the code above in your browser using DataLab